@@ -1,5 +1,7 @@
 export function foo() {
-    define("require", function(r) {
+    define([
+        "require"
+    ], function(r) {
         r("lodash");
     });
 }
